function burial_ages(data, muontype, sigma, consts, binres, makeplot, plotbanana)

%This function runs the burialage script for every row of the 'data' input
%file. See that script for details for the inputs and output file.


%obtain ages for each sample

datafile = load(data);

for k = 1:length(datafile(:,1))
    
    if nargin == 5
        [X, Y] = burialage(data, muontype, k, sigma, binres, consts);
    else if nargin == 6
            [X, Y] = burialage(data, muontype, k, sigma, binres, consts, 'true');
        else if nargin == 7
                [X, Y] = burialage(data, muontype, k, sigma, binres, consts, 'true', 'true');
            end
        end
    end
    
    pdf(k,:) = X;
    grid = Y;
end

%output concatenated pdfs (pre-convolution) with age bin (x-axis) to file for later use
save('pdfout.mat','pdf')
save('grid.mat','grid')

%convolution
rows = size(pdf,1);
cols = size(pdf,2);

Z = conv(pdf(1,:),pdf(2,:));
for k = 1:rows-2
    Z = conv(Z,pdf(k+2,:));
end

X1 = zeros(1,cols-1);
for k = 1:rows
    X1 = X1 + Z(k:rows:end-(rows-k));
end
convolved_pdf = horzcat(X1,[0]);

save('convolvedpdf.mat','convolved_pdf')

%plot convoluted pdf
figure
hold on
box on
xlabel('Burial Age (Ma)');
ylabel('normalized probability');
title('Convolved PDF');

plot(grid, convolved_pdf,'k-', 'linewidth', 2)

%plot individual pdfs
for k = 1:rows
    plot(grid, pdf(k,:),'b--', 'linewidth', 1)
end


end

